@@ -125,7 +125,7 @@ class ProjectVariables:
     project: str.lower
     warehouse: str.lower
     schema: str.lower
-
+    openai_secret: str
     role: str.lower
     password: str.lower
     database: str.lower
@@ -150,6 +150,11 @@ def assign_project_variables():
                     ProjectVariables.warehouse =  droughty_profile[value]['warehouse_name']                    
                     ProjectVariables.schema = droughty_profile[value]['schema_name']
 
+                    try:
+                        ProjectVariables.openai_secret = droughty_profile[value]['openai_secret']
+                    except:
+                        pass
+
                     # BigQuery
 
                     if ProjectVariables.warehouse == 'big_query':
@@ -244,6 +249,9 @@ class ExploresVariables:
     dbt_tests_filename: str.lower
     test_schemas: str.lower
 
+    openai_field_descriptions_path: str.lower
+    openai_field_descriptions_filename: str.lower
+
 
 def assign_explore_variables():
 
@@ -271,12 +279,25 @@ def assign_explore_variables():
                 ExploresVariables.dbml_filenames = (droughty_project.get("dbml_filenames"))  
                 ExploresVariables.dbt_tests_filename = (droughty_project.get("dbt_tests_filename"))
 
-                ExploresVariables.test_overwrite = droughty_project['test_overwrite']['models']
-                ExploresVariables.test_ignore = droughty_project['test_ignore']['models']
-                ExploresVariables.test_schemas = droughty_project['test_schemas']  
-
-                ExploresVariables.lookml_pop = droughty_project['lookml_pop']['views'] # If this is not at the bottom, it creates an error where other values will not fill. Something to look into
+                ExploresVariables.openai_field_descriptions_path = (droughty_project.get("openai_field_descriptions_path"))
+                ExploresVariables.openai_field_descriptions_filename = (droughty_project.get("openai_field_descriptions_filename"))
 
+                try:
+                    ExploresVariables.test_overwrite = droughty_project['test_overwrite']['models']
+                except:
+                    ExploresVariables.test_overwrite = "None"
+                try:
+                    ExploresVariables.test_ignore = droughty_project['test_ignore']['models']
+                except:
+                    ExploresVariables.test_ignore = "None"
+                try:
+                    ExploresVariables.test_schemas = droughty_project['test_schemas']  
+                except:
+                    ExploresVariables.test_schemas = "None"
+                try:
+                    ExploresVariables.lookml_pop = droughty_project['lookml_pop']['views'] # If this is not at the bottom, it creates an error where other values will not fill. Something to look into
+                except:
+                    ExploresVariables.lookml_pop = None
 
             except:
 
